@@ -1,7 +1,7 @@
 #
 # Kiwi: a Framework and Enhanced Widgets for Python
 #
-# Copyright (C) 2005 Async Open Source
+# Copyright (C) 2005-2006 Async Open Source
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -19,26 +19,35 @@
 # USA
 #
 # Author(s): Lorenzo Gil Sanchez <lgs@sicem.biz>
-#            Gustavo Rahal <gustavo@async.com.br>
 #            Johan Dahlin <jdahlin@async.com.br>
 #
 
-"""Data type converters with locale and currency support"""
+"""Data type converters with locale and currency support.
+
+Provides routines for converting data to and from strings.
+Simple example:
+
+    >>> from kiwi.datatypes import converter
+    >>> converter.from_string(int, '1,234')
+    '1234'
+    >>> converter.from_string(float, '1,234')
+    '1234.0'
+    >>> converter.to_string(currency, currency('10.5'))
+    '$10.50'
+"""
 
 import datetime
-import decimal
+from decimal import Decimal, InvalidOperation
 import locale
 import sys
 import time
 
 from kiwi import ValueUnset
 
-# by default locale uses the C locale but our date conversions use the user
-# locale so we need to set the locale to that one
-locale.setlocale(locale.LC_ALL, '') # this set the user locale ( $LANG )
-
 __all__ = ['ValidationError', 'lformat', 'converter', 'format_price']
 
+number = (int, float, long, Decimal)
+
 class ValidationError(Exception):
     pass
 
@@ -171,7 +180,11 @@ class _IntConverter(BaseConverter):
         """Convert a float to a string"""
         if format is None:
             format = '%d'
-        return lformat(format, value)
+
+        # Do not use lformat here, since an integer should always
+        # be formatted without thousand separators. Think of the
+        # use case of a port number, "3128" is desired, and not "3,128"
+        return format % value
 
     def from_string(self, value):
         "Convert a string to an integer"
@@ -219,61 +232,10 @@ converter.add(_BoolConverter)
 class _FloatConverter(BaseConverter):
     type = float
 
-    def _filter_locale(self, value):
-        """
-        Removes the locale specific data from the value string.
-        Currently we only remove the thousands separator and
-        convert the decimal point.
-        The returned value of this function can safely be passed to float()
-        """
-
-        conv = locale.localeconv()
-
-        # Check so we only have one decimal point
-        decimal_point = conv["decimal_point"]
-        decimal_points = value.count(decimal_point)
-        if decimal_points > 1:
-            raise ValidationError(
-                'You have more than one decimal point ("%s") '
-                ' in your number "%s"' % (decimal_point, value))
-
-        thousands_sep = conv["thousands_sep"]
-        if not thousands_sep:
-            return value
-
-        # Check so we don't have any thousand separators to the right
-        # of the decimal point
-        th_sep_count = value.count(thousands_sep)
-        if th_sep_count and decimal_points:
-            decimal_point_pos = value.index(decimal_point)
-            if thousands_sep in value[decimal_point_pos+1:]:
-                raise ValidationError("You have a thousand separator to the "
-                                      "right of the decimal point")
-            check_value = value[:decimal_point_pos]
-        else:
-            check_value = value
-
-        # Verify so the thousand separators are placed properly
-        # TODO: Use conv['grouping'] for locales where it's not 3
-        parts = check_value.split(thousands_sep)
-
-        # First part is a special case, It can be 1, 2 or 3
-        if 3 > len(parts[0]) < 1:
-            raise ValidationError("Inproperly placed thousands separator")
-
-        # Middle parts should have a length of 3
-        for part in parts[1:]:
-            if len(part) != 3:
-                raise ValidationError("Inproperly placed thousand "
-                                      "separators")
-
-        # Remove all thousand separators
-        return value.replace(thousands_sep, '')
-
     def as_string(self, value, format=None):
         """Convert a float to a string"""
         if format is None:
-            format = '%g'
+            return str(float(value))
         return lformat(format, value)
 
     def from_string(self, value):
@@ -282,29 +244,30 @@ class _FloatConverter(BaseConverter):
         if value == '':
             return ValueUnset
 
-        value = self._filter_locale(value)
-
+        value = filter_locale(value)
         try:
             retval = float(value)
         except ValueError:
-            raise ValidationError("This field requires a number")
+            raise ValidationError("This field requires a number, not %r" %
+                                  value)
 
         return retval
 
 converter.add(_FloatConverter)
 
 class _DecimalConverter(_FloatConverter):
-    type = decimal.Decimal
+    type = Decimal
     def from_string(self, value):
         if value == '':
             return ValueUnset
 
-        value = self._filter_locale(value)
+        value = filter_locale(value)
 
         try:
-            retval = decimal.Decimal(value)
-        except decimal.InvalidOperation:
-            raise ValidationError("This field requires a number")
+            retval = Decimal(value)
+        except InvalidOperation:
+            raise ValidationError("This field requires a number, not %r" %
+                                  value)
 
         return retval
 
@@ -318,6 +281,10 @@ class _BaseDateTimeConverter(BaseConverter):
     """
     date_format = None
 
+    def __init__(self):
+        self._keep_am_pm = False
+        self._keep_seconds = False
+
     def get_lang_constant(self):
         # This is a method and not a class variable since it does not
         # exist on all supported platforms, eg win32
@@ -342,9 +309,30 @@ class _BaseDateTimeConverter(BaseConverter):
 
     def get_format(self):
         if sys.platform == 'win32':
-            return self.date_format
+            format = self.date_format
         else:
-            return locale.nl_langinfo(self.get_lang_constant())
+            format = locale.nl_langinfo(self.get_lang_constant())
+
+        format = format.replace('%r', '%I:%M:%S %p')
+        format = format.replace('%T', '%H:%M:%S')
+
+        # Strip AM/PM
+        if not self._keep_am_pm:
+            if '%p' in format:
+                format = format.replace('%p', '')
+                # 12h -> 24h
+                format = format.replace('%I', '%H')
+
+        # Strip seconds
+        if not self._keep_seconds:
+            if '%S' in format:
+                format = format.replace('%S', '')
+
+        # Strip trailing characters
+        while format[-1] in ('.', ':', ' '):
+            format = format[:-1]
+
+        return format
 
     def as_string(self, value, format=None):
         "Convert a date to a string"
@@ -370,7 +358,6 @@ class _BaseDateTimeConverter(BaseConverter):
         try:
             # time.strptime (python 2.4) does not support %r
             # pending SF bug #1396946
-            format = format.replace('%r', '%I:%M:%S %p')
             dateinfo = time.strptime(value, format)
             return self.from_dateinfo(dateinfo)
         except ValueError:
@@ -418,12 +405,12 @@ class _ObjectConverter(BaseConverter):
     from_string = None
 converter.add(_ObjectConverter)
 
-class currency(decimal.Decimal):
+class currency(Decimal):
     """
     A datatype representing currency, used together with the list and
     the framework
     """
-    _converter = converter.get_converter(decimal.Decimal)
+    _converter = converter.get_converter(Decimal)
 
     def __new__(cls, value):
         """
@@ -435,17 +422,21 @@ class currency(decimal.Decimal):
             currency_symbol = conv.get('currency_symbol')
             text = value.strip(currency_symbol)
             value = currency._converter.from_string(text)
+            if value == ValueUnset:
+                raise InvalidOperation
         elif isinstance(value, float):
+            print ('Warning: losing precision converting float %r to currency'
+                   % value)
             value = str(value)
-        elif not isinstance(value, (int, long, decimal.Decimal)):
+        elif not isinstance(value, (int, long, Decimal)):
             raise TypeError(
                 "cannot convert %r of type %s to a currency" % (
                 value, type(value)))
 
-        return decimal.Decimal.__new__(cls, value)
+        return Decimal.__new__(cls, value)
 
     def format(self, symbol=True, precision=None):
-        value = decimal.Decimal(self)
+        value = Decimal(self)
 
         conv = locale.localeconv()
 
@@ -536,7 +527,7 @@ class currency(decimal.Decimal):
     def __repr__(self):
         return '<currency %s> ' % self.format()
 
-class _CurrencyConverter(BaseConverter):
+class _CurrencyConverter(_DecimalConverter):
     type = currency
 
     def __init__(self):
@@ -558,7 +549,7 @@ class _CurrencyConverter(BaseConverter):
             return ValueUnset
         try:
             return currency(value)
-        except ValueError:
+        except (ValueError, InvalidOperation):
             raise ValidationError(
                 "%s can not be converted to a currency" % value)
 
@@ -578,3 +569,64 @@ def format_price(value, symbol=True, precision=None):
     """
 
     return currency(value).format(symbol, precision)
+
+def filter_locale(value):
+    """
+    Removes the locale specific data from the value string.
+    Currently we only remove the thousands separator and
+    convert the decimal point.
+    The returned value of this function can safely be passed to float()
+
+    @param value: value to convert
+    @returns: the value without locale specific data
+    """
+
+    conv = locale.localeconv()
+
+    # Check so we only have one decimal point
+    decimal_point = conv["decimal_point"]
+    decimal_points = value.count(decimal_point)
+    if decimal_points > 1:
+        raise ValidationError(
+            'You have more than one decimal point ("%s") '
+            ' in your number "%s"' % (decimal_point, value))
+
+    thousands_sep = conv["thousands_sep"]
+    if thousands_sep:
+        # Check so we don't have any thousand separators to the right
+        # of the decimal point
+        th_sep_count = value.count(thousands_sep)
+        if th_sep_count and decimal_points:
+            decimal_point_pos = value.index(decimal_point)
+            if thousands_sep in value[decimal_point_pos+1:]:
+                raise ValidationError("You have a thousand separator to the "
+                                      "right of the decimal point")
+            check_value = value[:decimal_point_pos]
+        else:
+            check_value = value
+
+        # Verify so the thousand separators are placed properly
+        # TODO: Use conv['grouping'] for locales where it's not 3
+        parts = check_value.split(thousands_sep)
+
+        # First part is a special case, It can be 1, 2 or 3
+        if 3 > len(parts[0]) < 1:
+            raise ValidationError("Inproperly placed thousands separator")
+
+        # Middle parts should have a length of 3
+        for part in parts[1:]:
+            if len(part) != 3:
+                raise ValidationError("Inproperly placed thousand "
+                                      "separators")
+
+        # Remove all thousand separators
+        value = value.replace(thousands_sep, '')
+
+    # Replace all decimal points with .
+    if decimal_point != '.':
+        value = value.replace(decimal_point, '.')
+    return value
+
+# by default locale uses the C locale but our date conversions use the user
+# locale so we need to set the locale to that one
+locale.setlocale(locale.LC_ALL, '') # this set the user locale ( $LANG )
