@@ -33,6 +33,8 @@ from kiwi.python import namedAny
 __all__ = ['Application', 'Library', 'app', 'environ', 'require_gazpacho',
            'is_gazpacho_required']
 
+EnvironmentError = EnvironmentError
+
 # From http://tinyurl.com/77ukj
 def _is_frozen():
     "Helper function to check if we're frozen in a py2exe'd file"
@@ -216,13 +218,21 @@ class Library(Environment):
                            charset='utf-8'):
         if not domain:
             domain = self.name
-
         # XXX: locale should not be a list
         localedir = self._resources.get(locale)
         if localedir:
             gettext.bindtextdomain(domain, localedir[0])
+        else:
+            print 'Warning, no localedir for: %s' % domain
         gettext.bind_textdomain_codeset(domain, charset)
 
+    def set_application_domain(self, domain):
+        """
+        Sets the default application domain
+        @param domain: the domain
+        """
+        gettext.textdomain(domain)
+
     def add_global_resource(self, resource, path):
         """Convenience method to add a global resource.
         This is the same as calling kiwi.environ.environ.add_resource
@@ -235,7 +245,7 @@ class Library(Environment):
             self.add_global_resource(resource, path)
 
 class Application(Library):
-    """Application extends a L{library}. It's meant to be used
+    """Application extends a L{Library}. It's meant to be used
     by applications
 
     Libraries are usually instantiated in __init__.py in the topmost package
@@ -269,7 +279,7 @@ class Application(Library):
     def _get_main(self):
         try:
             module = namedAny(self._path)
-        except (ValueError, AttributeError, ImportError), e:
+        except ImportError, e:
             raise SystemExit("ERROR: Could not find item '%s', %s" %
                              (self._path, e))
 
@@ -285,7 +295,11 @@ class Application(Library):
             domain = self.name
 
         Library.enable_translation(self, domain, locale, charset)
-        gettext.textdomain(domain)
+        old_domain = gettext.textdomain()
+        if old_domain  != 'messages':
+            print 'Warning: overriding default domain, was %s' % old_domain
+
+        self.set_application_domain(domain)
 
     def run(self):
         main = self._get_main()
@@ -309,4 +323,3 @@ def is_gazpacho_required():
 environ = Environment()
 
 app = None
-
