@@ -85,18 +85,24 @@ class IconEntry(object):
     def __init__(self, entry):
         if not isinstance(entry, gtk.Entry):
             raise TypeError("entry must be a gtk.Entry")
+        self._constructed = False
         self._pixbuf = None
         self._pixw = 1
         self._pixh = 1
         self._text_area = None
-        self._text_area_size = (1, 1)
+        self._text_area_pos = (0, 0)
         self._icon_win = None
         self._entry = entry
-        self._constructed = False
-        self._entry.connect('enter-notify-event',
-                            self._on_entry__enter_notify_event)
-        self._entry.connect('leave-notify-event',
-                            self._on_entry__leave_notify_event)
+        entry.connect('enter-notify-event',
+                      self._on_entry__enter_notify_event)
+        entry.connect('leave-notify-event',
+                      self._on_entry__leave_notify_event)
+        entry.connect('notify::xalign',
+                      self._on_entry__notify_xalign)
+        self._update_position()
+
+    def _on_entry__notify_xalign(self, entry, pspec):
+        self._update_position()
 
     def _on_entry__enter_notify_event(self, entry, event):
         icon_win = self.get_icon_window()
@@ -169,6 +175,7 @@ class IconEntry(object):
 
         # Hack: Save a reference to the text area, now when its created
         self._text_area = entry.window.get_children()[0]
+        self._text_area_pos = self._text_area.get_position()
 
         # PyGTK should allow default values for most of the values here.
         win = gtk.gdk.Window(entry.window,
@@ -210,14 +217,25 @@ class IconEntry(object):
         if not self._pixbuf:
             return
 
+        icony = iconx = 4
+
         # Make space for the icon, both windows
         winw = self._entry.window.get_size()[0]
         textw, texth = self._text_area.get_size()
-        textw = winw - self._pixw - 8
-        self._text_area.resize(textw, texth)
+        textw = winw - self._pixw - (iconx + icony)
+
+        if self._pos == gtk.POS_LEFT:
+            textx, texty = self._text_area_pos
+            textx += iconx + self._pixw
+
+            # FIXME: Why is this needed. Focus padding?
+            #        The text jumps without this
+            textw -= 2
+            self._text_area.move_resize(textx, texty, textw, texth)
+        elif self._pos == gtk.POS_RIGHT:
+            self._text_area.resize(textw, texth)
+            iconx += textw
 
-        iconx = 4 + textw
-        icony = 4
         icon_win = self._icon_win
         # XXX: Why?
         if not icon_win:
@@ -250,3 +268,8 @@ class IconEntry(object):
             win.draw_pixbuf(None, self._pixbuf, 0, 0, 0, 0,
                             self._pixw, self._pixh)
 
+    def _update_position(self):
+        if self._entry.get_property('xalign') > 0.5:
+            self._pos = gtk.POS_LEFT
+        else:
+            self._pos = gtk.POS_RIGHT
