@@ -27,7 +27,6 @@
 """High level wrapper for GtkTreeView"""
 
 import datetime
-import decimal
 import gettext
 
 import gobject
@@ -36,7 +35,7 @@ from gtk import gdk
 
 from kiwi import _warn
 from kiwi.accessors import kgetattr
-from kiwi.datatypes import converter, currency, lformat
+from kiwi.datatypes import converter, currency, lformat, number
 from kiwi.decorators import deprecated
 from kiwi.python import slicerange
 from kiwi.utils import PropertyObject, gsignal, gproperty, type_register
@@ -65,7 +64,6 @@ class Column(PropertyObject, gobject.GObject):
     gproperty('width', int, maximum=2**16)
     gproperty('sorted', bool, default=False)
     gproperty('order', gtk.SortType, default=gtk.SORT_ASCENDING)
-    #gproperty('title_pixmap', str)
     gproperty('expand', bool, default=False)
     gproperty('tooltip', str)
     gproperty('format_func', object)
@@ -75,6 +73,8 @@ class Column(PropertyObject, gobject.GObject):
     gproperty('cache', bool, default=False)
     gproperty('use-stock', bool, default=False)
     gproperty('icon-size', gtk.IconSize, default=gtk.ICON_SIZE_MENU)
+    gproperty('editable_attribute', str)
+    #gproperty('title_pixmap', str)
 
     # This can be set in subclasses, to be able to allow custom
     # cell_data_functions, used by SequentialColumn
@@ -91,7 +91,7 @@ class Column(PropertyObject, gobject.GObject):
     def __init__(self, attribute, title=None, data_type=None, **kwargs):
         """
         Creates a new Column, which describes how a column in a
-        List should be rendered.
+        ObjectList should be rendered.
 
         @param attribute: a string with the name of the instance attribute the
             column represents.
@@ -105,17 +105,17 @@ class Column(PropertyObject, gobject.GObject):
         @keyword justify: one of gtk.JUSTIFY_LEFT, gtk.JUSTIFY_RIGHT or
             gtk.JUSTIFY_CENTER or None. If None, the justification will be
             determined by the type of the attribute value of the first
-            instance to be inserted in the List (integers and floats
-            will be right-aligned).
+            instance to be inserted in the ObjectList (numbers will be
+            right-aligned).
         @keyword format: a format string to be applied to the attribute
             value upon insertion in the list.
         @keyword width: the width in pixels of the column, if not set, uses the
-            default to List. If no Column specifies a width,
-            columns_autosize() will be called on the List upon append()
+            default to ObjectList. If no Column specifies a width,
+            columns_autosize() will be called on the ObjectList upon append()
             or the first add_list().
-        @keyword sorted: whether or not the List is to be sorted by this
+        @keyword sorted: whether or not the ObjectList is to be sorted by this
             column.
-            If no Columns are sorted, the List will be created unsorted.
+            If no Columns are sorted, the ObjectList will be created unsorted.
         @keyword order: one of gtk.SORT_ASCENDING or gtk.SORT_DESCENDING or
             -1. The value -1 is used internally when the column is not sorted.
         @keyword expand: if set column will expand. Note: this space is shared
@@ -141,6 +141,8 @@ class Column(PropertyObject, gobject.GObject):
             value which should be a stock id.
         @keyword icon_size: a gtk.IconSize constant, gtk.ICON_SIZE_MENU if not
             specified.
+        @keyword editable_attribute: a string which is the attribute
+            which should decide if the cell is editable or not.
         @keyword title_pixmap: (TODO) if set to a filename a pixmap will be
             used *instead* of the title set. The title string will still be
             used to identify the column in the column selection and in a
@@ -169,7 +171,7 @@ class Column(PropertyObject, gobject.GObject):
             if data_type:
                 if issubclass(data_type, bool):
                     kwargs['justify'] = gtk.JUSTIFY_CENTER
-                elif issubclass(data_type, (int, float, long, currency)):
+                elif issubclass(data_type, (number, currency)):
                     kwargs['justify'] = gtk.JUSTIFY_RIGHT
 
         format_func = kwargs.get('format_func')
@@ -180,6 +182,13 @@ class Column(PropertyObject, gobject.GObject):
                 raise TypeError(
                     "format and format_func can not be used at the same time")
 
+        # editable_attribute always turns on editable
+        if 'editable_attribute' in kwargs:
+            if not kwargs.get('editable', True):
+                raise TypeError(
+                    "editable cannot be disabled when using editable_attribute")
+            kwargs['editable'] = True
+
         PropertyObject.__init__(self, **kwargs)
         gobject.GObject.__init__(self)
 
@@ -293,8 +302,8 @@ class ColoredColumn(Column):
 
     def __init__(self, attribute, title=None, data_type=None,
                  color=None, data_func=None, **kwargs):
-        if not issubclass(data_type, (int, float)):
-            raise TypeError("data type must be int or float")
+        if not issubclass(data_type, number):
+            raise TypeError("data type must be a number")
         if not callable(data_func):
             raise TypeError("data func must be callable")
 
@@ -318,6 +327,7 @@ class ColoredColumn(Column):
         renderer.set_property('foreground-gdk', color)
 
 class _ContextMenu(gtk.Menu):
+
     """
     ContextMenu is a wrapper for the menu that's displayed when right
     clicking on a column header. It monitors the treeview and rebuilds
@@ -355,6 +365,8 @@ class _ContextMenu(gtk.Menu):
 
         for column in self._treeview.get_columns():
             header_widget = column.get_widget()
+            if not header_widget:
+                continue
             title = header_widget.get_text()
 
             menuitem = gtk.CheckMenuItem(title)
@@ -436,7 +448,7 @@ class ObjectList(PropertyObject, gtk.ScrolledWindow):
     # emitted when empty or non-empty status changes
     gsignal('has-rows', bool)
 
-    # this property is used to serialize the columns of a List. The format
+    # this property is used to serialize the columns of a ObjectList. The format
     # is a big string with '^' as the column separator and '|' as the field
     # separator
     gproperty('column-definitions', str, nick="ColumnDefinitions")
@@ -947,7 +959,7 @@ class ObjectList(PropertyObject, gtk.ScrolledWindow):
             if column.editable:
                 raise TypeError("use-stock columns cannot be editable")
         elif issubclass(data_type, (datetime.date, datetime.time,
-                                    basestring, int, float, decimal.Decimal,
+                                    basestring, number,
                                     currency)):
             renderer = gtk.CellRendererText()
             prop = 'text'
@@ -973,6 +985,17 @@ class ObjectList(PropertyObject, gtk.ScrolledWindow):
                              (column, renderer_prop, as_string)):
 
         row = model[treeiter]
+        if column.editable_attribute:
+            data = column.get_attribute(row[COL_MODEL],
+                                        column.editable_attribute, None)
+            data_type = column.data_type
+            if isinstance(renderer, gtk.CellRendererToggle):
+                renderer.set_property('activatable', data)
+            elif isinstance(renderer, gtk.CellRendererText):
+                renderer.set_property('editable', data)
+            else:
+                raise AssertionError
+
         if column.cache:
             cache = self._cell_data_caches[column.attribute]
             path = row.path[0]
@@ -1020,7 +1043,7 @@ class ObjectList(PropertyObject, gtk.ScrolledWindow):
 
     def _on_renderer__edited(self, renderer, path, value, column):
         data_type = column.data_type
-        if data_type in (int, float):
+        if data_type in number:
             value = data_type(value)
 
         # XXX convert new_text to the proper data type
@@ -1091,7 +1114,14 @@ class ObjectList(PropertyObject, gtk.ScrolledWindow):
         self.emit('selection-changed', item)
 
     def _after_treeview__row_activated(self, treeview, path, view_column):
-        self.emit('double-click', self._model[path][COL_MODEL])
+        try:
+            row = self._model[path]
+        except IndexError:
+            print 'path %s was not found in model: %s' % (
+                path, map(list, self._model))
+            return
+
+        self.emit('double-click', row[COL_MODEL])
 
     # hacks
     def _get_column_button(self, column):
@@ -1265,17 +1295,29 @@ class ObjectList(PropertyObject, gtk.ScrolledWindow):
             if path in cache:
                 del cache[path]
 
-    def remove(self, instance):
+    def remove(self, instance, select=False):
         """Remove an instance from the list.
         If the instance is not in the list it returns False. Otherwise it
         returns True.
+
+        @param instance:
+        @param select: if true, the previous item will be selected
+          if there is one.
         """
 
         objid = id(instance)
         if not objid in self._iters:
             raise ValueError("instance %r is not in the list" % instance)
 
-        return self._remove(objid)
+
+        if select:
+            prev = self.get_previous(instance)
+            rv = self._remove(objid)
+            if prev != instance:
+                self.select(prev)
+        else:
+            rv = self._remove(objid)
+        return rv
 
     def update(self, instance):
         objid = id(instance)
@@ -1438,7 +1480,7 @@ class ObjectList(PropertyObject, gtk.ScrolledWindow):
             pos += 1
         return model[pos][COL_MODEL]
 
-    def get_previous(self, instance=False):
+    def get_previous(self, instance):
         """
         Returns the item before instance in the list.
         Note that the instance must be inserted before this can be called
@@ -1520,7 +1562,7 @@ class ListLabel(gtk.HBox):
     def __init__(self, klist, column, label='', value_format='%s'):
         """
         @param klist:        list to follow
-        @type klist:         kiwi.ui.widget.list.List
+        @type klist:         kiwi.ui.objectlist.ObjectList
         @param column:       name of a column in a klist
         @type column:        string
         @param label:        label
@@ -1623,13 +1665,13 @@ class ListLabel(gtk.HBox):
 class SummaryLabel(ListLabel):
     """I am a subclass of ListLabel which you can use if you want
     to summarize all the values of a specific column.
-    Please note that I only know how to handle int and float column
+    Please note that I only know how to handle number column
     data types and I will complain if you give me something else."""
 
     def __init__(self, klist, column, label=_('Total:'), value_format='%s'):
         ListLabel.__init__(self, klist, column, label, value_format)
-        if not issubclass(self._column.data_type, (int, float, decimal.Decimal)):
-            raise TypeError("data_type of column must be int or float, not %r",
+        if not issubclass(self._column.data_type, number):
+            raise TypeError("data_type of column must be a number, not %r",
                             self._column.data_type)
         klist.connect('cell-edited', self._on_klist__cell_edited)
         self.update_total()
@@ -1664,4 +1706,3 @@ class SummaryLabel(ListLabel):
 
     def _on_klist__cell_edited(self, klist, object, attribute):
         self.update_total()
-
