@@ -54,7 +54,7 @@ class TimeOutError(Exception):
     """
     pass
 
-log = Logger('test')
+log = Logger('uitest')
 
 class ThreadSafeFunction:
     """
@@ -68,8 +68,9 @@ class ThreadSafeFunction:
 
     def _invoke(self, *args, **kwargs):
         gdk.threads_enter()
-        log('Calling %s.%s(%r)' % (self._obj_name,
-                                   self._func.__name__, args))
+        log('Calling %s.%s(%s)' % (self._obj_name,
+                                   self._func.__name__,
+                                   ', '.join(map(repr, args))))
         self._func(*args, **kwargs)
         gdk.threads_leave()
         return False
@@ -243,4 +244,3 @@ class Player(Base):
 
         while self._appthread.isAlive():
             time.sleep(0.1)
-
