@@ -371,6 +371,20 @@ class SlaveView(gobject.GObject):
     # GTK+ proxies and convenience functions
     #
 
+    def show_and_loop(self, parent=None):
+        """
+        Runs show() and runs the GTK+ event loop. If the parent
+        argument is supplied and is a valid view, this view is set as a
+        transient for the parent view
+
+        @param parent:
+        """
+
+        self.show()
+        if parent:
+            self.set_transient_for(parent)
+        gtk.main()
+
     def show(self, *args):
         """Shows the toplevel widget"""
         self.toplevel.show()
@@ -699,6 +713,9 @@ class SlaveView(gobject.GObject):
                 not isinstance(widget, MixinSupportValidation)):
                 continue
 
+            if not isinstance(widget, MixinSupportValidation):
+                continue
+
             try:
                 widget.connect_object('validation-changed',
                                       self._on_child__validation_changed,
