@@ -7,17 +7,17 @@
 # modify it under the terms of the GNU Lesser General Public
 # License as published by the Free Software Foundation; either
 # version 2.1 of the License, or (at your option) any later version.
-# 
+#
 # This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 # Lesser General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 # USA
-# 
+#
 # Author(s): Lorenzo Gil Sanchez <lgs@sicem.biz>
 #            Gustavo Rahal <gustavo@async.com.br>
 #
@@ -34,21 +34,26 @@ from kiwi.ui.widgets.proxy import WidgetMixin
 from kiwi.utils import PropertyObject
 
 class Label(PropertyObject, gtk.Label, WidgetMixin):
-    def __init__(self):
-        gtk.Label.__init__(self)
-        PropertyObject.__init__(self)
+    def __init__(self, label='', data_type=None):
+        """
+        @param label: initial text
+        @param data_type: data type of label
+        """
+        gtk.Label.__init__(self, label)
+        PropertyObject.__init__(self, data_type=data_type)
         WidgetMixin.__init__(self)
         self.set_use_markup(True)
         self._attr_dic = { "style": None,
                            "weight": None,
-                           "size": None}
+                           "size": None,
+                           "underline": None}
         self._size_list = ('xx-small', 'x-small',
                            'small', 'medium',
                            'large', 'x-large',
                            'xx-large')
-        
+
         self.connect("notify::label", self._on_label_changed)
-    
+
     def _on_label_changed(self, label, param):
         # Since most of the time labels do not have a model attached to it
         # we should just emit a signal if a model is defined
@@ -64,48 +69,49 @@ class Label(PropertyObject, gtk.Label, WidgetMixin):
         else:
             text = self._as_string(data)
         self.set_text(text)
-    
+
     def _apply_attributes(self):
-        # join the attributes
-        attr_str = ''
         # sorting is been done so we can be sure of the order of the
         # attributes. Helps writing tests cases
-        keys = self._attr_dic.keys()
+        attrs = self._attr_dic
+        keys = attrs.keys()
         keys.sort()
-        for key in keys:
-            if self._attr_dic[key] is not None:
-                attr_str +=  '%s="%s" '%(key, self._attr_dic[key])
-        label_str = '<span %s>%s</span>'%(attr_str, self.get_text())
-        
-        self.set_markup(label_str)
-        
-    def set_bold(self, value):
-        """ If True set the text to bold. False sets the text to normal """
+
+        attr_pairs = ['%s="%s"' % (key, attrs[key]) for key in keys
+                                                        if attrs[key]]
+        self.set_markup('<span %s>%s</span>' % (' '.join(attr_pairs),
+                                                self.get_text()))
+
+    def _set_text_attribute(self, attribute_name, attr, value):
         if value:
-            if self._attr_dic["weight"] is None:
-                self._attr_dic["weight"] = "bold"
+            if self._attr_dic[attribute_name] is None:
+                self._attr_dic[attribute_name] = attr
                 self._apply_attributes()
         else:
-            if self._attr_dic["weight"] is not None:
-                self._attr_dic["weight"] = None
+            if self._attr_dic[attribute_name] is not None:
+                self._attr_dic[attribute_name] = None
                 self._apply_attributes()
 
+    def set_bold(self, value):
+        """ If True set the text to bold. False sets the text to normal """
+        self._set_text_attribute("weight", "bold", value)
+
     def set_italic(self, value):
-        """
-        Enable or disable italic text
+        """ Enable or disable italic text
         @param value: Allowed values:
-          - True set the text to italic
-          - False sets the text to normal
+          - True: enable Italic attribute
+          - False: disable Italic attribute
         """
-        if value:
-            if self._attr_dic["style"] is None:
-                self._attr_dic["style"] = "italic"
-                self._apply_attributes()
-        else:
-            if self._attr_dic["style"] is not None:
-                self._attr_dic["style"] = None
-                self._apply_attributes()
-    
+        self._set_text_attribute("style", "italic", value)
+
+    def set_underline(self, value):
+        """ Enable or disable underlined text
+        @param value: Allowed values:
+          - True: enable Underline attribute
+          - Fase: disable Underline attribute
+        """
+        self._set_text_attribute("underline", "single", value)
+
     def set_size(self, size=None):
         """ Set the size of the label. If size is empty the label will be
         set to the default size.
@@ -119,7 +125,6 @@ class Label(PropertyObject, gtk.Label, WidgetMixin):
           - xx-large
         @type size: string
         """
-
         if (size is not None and
             size not in self._size_list):
             raise ValueError('Size of "%s" label is not valid' %
@@ -127,16 +132,15 @@ class Label(PropertyObject, gtk.Label, WidgetMixin):
 
         self._attr_dic["size"] = size
         self._apply_attributes()
-    
+
     def set_text(self, text):
         """ Overrides gtk.Label set_text method. Sets the new text of
         the label but keeps the formating
         @param text: label
         @type text: string
         """
-        
         gtk.Label.set_text(self, text)
         self._apply_attributes()
 
     def set_color(self, color):
-       set_foreground(self, color) 
+        set_foreground(self, color)
