@@ -32,6 +32,7 @@ L{kiwi.ui.icon.IconEntry}
 
 import gtk
 
+from kiwi.datatypes import number
 from kiwi.ui.icon import IconEntry
 from kiwi.ui.widgets.proxy import WidgetMixinSupportValidation
 from kiwi.utils import PropertyObject, gsignal
@@ -43,7 +44,7 @@ class SpinButton(PropertyObject, gtk.SpinButton, WidgetMixinSupportValidation):
     The only allowed types for spinbutton are int and float.
 
     """
-    allowed_data_types = int, float
+    allowed_data_types = number
 
     def __init__(self):
         # since the default data_type is str we need to set it to int
@@ -52,6 +53,7 @@ class SpinButton(PropertyObject, gtk.SpinButton, WidgetMixinSupportValidation):
         PropertyObject.__init__(self, data_type=int)
         WidgetMixinSupportValidation.__init__(self)
         self._icon = IconEntry(self)
+        self.set_property('xalign', 1.0)
 
     # GtkEditable.changed is called too often
     # GtkSpinButton.value-changed is called only when the value changes
@@ -83,7 +85,7 @@ class SpinButton(PropertyObject, gtk.SpinButton, WidgetMixinSupportValidation):
 
         self.chain(allocation)
 
-	if self.flags() & gtk.REALIZED:
+        if self.flags() & gtk.REALIZED:
             self._icon.resize_windows()
 
     def do_realize(self):
