@@ -1,4 +1,5 @@
-from datetime import date
+from decimal import Decimal
+import datetime
 import unittest
 import locale
 
@@ -17,7 +18,7 @@ def set_locale(category, name):
 
 class DataTypesTest(unittest.TestCase):
     def setUp(self):
-        self.date = date(1979, 2, 12)
+        self.date = datetime.date(1979, 2, 12)
         self.conv = converter.get_converter(bool)
 
     def testFromString(self):
@@ -35,8 +36,8 @@ class DataTypesTest(unittest.TestCase):
 
 class DateTest(unittest.TestCase):
     def setUp(self):
-        self.date = date(1979, 2, 12)
-        self.conv = converter.get_converter(date)
+        self.date = datetime.date(1979, 2, 12)
+        self.conv = converter.get_converter(datetime.date)
 
     def tearDown(self):
         set_locale(locale.LC_ALL, 'C')
@@ -54,7 +55,7 @@ class DateTest(unittest.TestCase):
 
         self.assertEqual(self.conv.as_string(self.date), "12/02/79")
 
-    def tesFromStringBR(self):
+    def testFromStringBR(self):
         if not set_locale(locale.LC_TIME, 'pt_BR'):
             return
 
@@ -85,16 +86,19 @@ class CurrencyTest(unittest.TestCase):
             return
 
         self.assertEqual(currency(100).format(), 'R$100')
-        self.assertEqual(currency(123.45).format(), 'R$123,45')
+        self.assertEqual(currency('123.45').format(), 'R$123,45')
         self.assertEqual(currency(12345).format(), 'R$12.345')
         self.assertEqual(currency(-100).format(), 'R$-100')
 
+        # Sometimes it works, sometimes it doesn't
+        #self.assertEqual(self.conv.from_string('0,5'), currency('0.5'))
+
     def testFormatUS(self):
         if not set_locale(locale.LC_MONETARY, 'en_US'):
             return
 
         self.assertEqual(currency(100).format(), '$100')
-        self.assertEqual(currency(123.45).format(), '$123.45')
+        self.assertEqual(currency('123.45').format(), '$123.45')
         self.assertEqual(currency(12345).format(), '$12,345')
         self.assertEqual(currency(-100).format(), '$-100')
         self.assertEqual(currency(1).format(True), '$1')
@@ -103,6 +107,7 @@ class CurrencyTest(unittest.TestCase):
 
         self.assertEqual(self.conv.from_string(''), ValueUnset)
         self.assertEqual(self.conv.from_string('0'), currency(0))
+        self.assertEqual(self.conv.from_string('0.5'), currency('0.5'))
         self.assertRaises(ValidationError, self.conv.from_string, 'foo')
 
         self.assertEqual(self.conv.as_string(currency(0)), '$0.00')
@@ -126,6 +131,9 @@ class IntTest(unittest.TestCase):
     def setUp(self):
         self.conv = converter.get_converter(int)
 
+    def tearDown(self):
+        set_locale(locale.LC_ALL, 'C')
+
     def testFromString(self):
         self.assertEqual(self.conv.from_string('0'), 0)
         self.assertRaises(ValidationError, self.conv.from_string, '0.5')
@@ -134,6 +142,12 @@ class IntTest(unittest.TestCase):
         self.assertEqual(self.conv.as_string(0), '0')
         self.assertEqual(self.conv.as_string(-10), '-10')
 
+    def testAsStringUS(self):
+        if not set_locale(locale.LC_NUMERIC, 'en_US'):
+            return
+
+        self.assertEqual(self.conv.as_string(123456789), '123456789')
+
 class FloatTest(unittest.TestCase):
     def setUp(self):
         self.conv = converter.get_converter(float)
@@ -176,7 +190,19 @@ class FloatTest(unittest.TestCase):
     def testAsString(self):
         self.assertEqual(self.conv.as_string(0.5), '0.5')
         self.assertEqual(self.conv.as_string(-10.5), '-10.5')
-        self.assertEqual(self.conv.as_string(0.5), '0.5')
+        self.assertEqual(self.conv.as_string(0.12345), '0.12345')
+        self.assertEqual(self.conv.as_string(10000000), '10000000.0')
+
+class DecimalTest(unittest.TestCase):
+    def setUp(self):
+        self.conv = converter.get_converter(Decimal)
+
+    def testFromString(self):
+        self.assertEqual(self.conv.from_string('-2.5'), Decimal('-2.5'))
+        self.assertEqual(self.conv.from_string('10.33'), Decimal('10.33'))
+        self.assertRaises(ValidationError, self.conv.from_string, 'foo')
+        self.assertRaises(ValidationError, self.conv.from_string, '1.2.3')
+        self.assertEqual(self.conv.from_string(''), ValueUnset)
 
 if __name__ == "__main__":
     unittest.main()
